# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/rugbypy',
                'doc_host': 'https://seanyboi.github.io',
                'git_url': 'https://github.com/seanyboi/rugbypy',
                'lib_path': 'rugbypy'},
  'syms': { 'rugbypy.match': { 'rugbypy.match.fetch_match_details': ('match.html#fetch_match_details', 'rugbypy/match.py'),
                               'rugbypy.match.fetch_matches': ('match.html#fetch_matches', 'rugbypy/match.py')},
            'rugbypy.player': {'rugbypy.player.fetch_player_stats': ('player.html#fetch_player_stats', 'rugbypy/player.py')},
            'rugbypy.team': {'rugbypy.team.fetch_team_stats': ('team.html#fetch_team_stats', 'rugbypy/team.py')}}}
